步履不停 (豆瓣)
Description: 步履不停电影简介和剧情介绍,步履不停影评、图片、预告片、影讯、论坛、在线购票
Keywords: 步履不停,歩いても 歩いても,步履不停影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.229豆瓣电影Top250

# 步履不停 歩いても 歩いても (2008)

导演: 是枝裕和
编剧: 是枝裕和
主演: 阿部宽 / 夏川结衣 / 江原由希子 / 高桥和也 / 田中祥平 / 野本萤 / 林凌雅 / 寺岛进 / 加藤治子 / 树木希林 / 原田芳雄
类型: 剧情 / 家庭
制片国家/地区: 日本
语言: 日语
上映日期: 2008-06-28(日本)
片长: 115分钟
又名: 横山家之味(港/台) / 步伐不停 / 即使你走啊走 / 安静的行走 / Still Walking / Even If You Walk and Walk
IMDb: tt1087578
豆瓣评分
引用
8.8
264312人评价
5星
50.8%
4星
40.5%
3星
8.0%
2星
0.6%
1星
0.2%
好于 97% 家庭片
好于 97% 剧情片
想看 看过
评价:
推荐

## 步履不停的剧情简介 · · · · · ·

“人生路上步履不停，为何总是慢一拍”。
位于偏远小镇的横山一家，生活平静祥和。父亲恭平（原田芳雄 饰）是业已退休的医生，却时时牵挂小镇诊所内的事务。长子纯平继承了父亲的事业，却在15年前为救落水儿童而溺水身亡。次子良多（阿部宽 饰）与父亲意见相左，执意前往异地当起了绘画修复师。多年的打拼换来的却是失业，困顿的良多与带着孩子的由香里（夏川结衣 饰）结婚，相互扶持，继续生活。
又逢纯平的忌日，良多和姐姐千奈美（YOU 饰）带着家人分别赶回家中。平静的横山家再次热闹起来……
本片荣获2009年蓝丝带最佳导演奖和最佳女配角奖（树木希林）、2008年报知电影和2009年电影旬报最佳女配角（树木希林）、2009年每日电影奖最佳男主角（阿部宽）、2008年马塔布拉塔国际电影节评审团大奖和最佳影片。 ©豆瓣

## 步履不停的演职员 · · · · · · ( 全部 15 )

- 是枝裕和 导演
- 阿部宽 饰 横山良多
- 夏川结衣 饰 由加利
- 江原由希子 饰 千奈美
- 高桥和也 饰 信夫
- 田中祥平 饰 横山淳

## 步履不停的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片740 · 添加 )

## 步履不停的获奖情况 · · · · · · ( 全部 )

- 第32届日本电影学院奖
- 最佳女配角(提名)
- 树木希林

- 第3届亚洲电影大奖
- 最佳导演
- 是枝裕和

- 第33届报知映画赏
- 最佳女配角
- 树木希林

## 喜欢这部电影的人也喜欢 · · · · · ·

  比海更深

  如父如子

  海街日记

  东京物语

  饮食男女

  奇迹

  一一

  小偷家族

  海边的曼彻斯特

  一次别离

我要写短评

## 步履不停的短评 · · · · · · ( 全部 81760 条 )

热门 / 最新 / 好友

### 3607 有用 亵渎电影 看过 2009-09-10 02:38:25

亲人只有一次的缘分，无论这辈子我和你会相处多久，也请好好珍惜共聚的时光，下辈子，无论爱与不爱，都不会再见。★★★★★

### 2455 有用 达到厂 看过 2011-01-17 14:45:59

日本的家庭电影已经是世界巅峰了，步履不停是巅峰中的佳作。

### 3068 有用 萨嘎摩哆熊猫桑 看过 2010-03-23 10:10:52

人生就这么步履不停地前行着，那些舍得的舍不得的人和事总会一一远去，以至再也无法望见。你可能偶尔怀念，也可能丢了命似的道不了别。

### 1876 有用 Q。 看过 2011-02-09 21:29:47

"你才25岁，你可以成为任何你想成为的人。"剧情没有什么起伏，不温不火，朴实平淡的对话，安静的生活，温馨的生活细节，这样讲出来的故事，总是娓娓动人。生命依旧不停的在循环，平淡、责任、羁绊、也许，这也叫做人生吧。当最后那只黄粉蝶飞出来的时候，却让人眼泪止不住的在流。★★★★☆

### 1704 有用 水仙操 看过 2011-09-05 18:52:46

送走儿子后寡言的医生父亲念叨：“下次来的时候就是新年了。”与此同时儿子坐在远行的大巴上长舒一口气：“这次回家了新年之行总算可以省了。”转瞬下一个镜头就变成空的风景和儿子的画外音：三年后父亲死了。不多久母亲也走了，她最终也没坐上我买的车。这是日影特有的温情与残酷。玉米天妇罗。

> 更多短评 81760条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 步履不停的影评 · · · · · · ( 全部 1466 条 )

热门 / 最新 / 好友
艾小柯 2009-08-10 06:46:57

## 逝者如斯夫

我喜欢逛日本超市，吃日本菜，自然也爱看电影里日本人做家务。 旧金山日本城购物中心二楼的廉价超市里有好多有趣的玩意儿：将白水煮蛋煮成小汽车或者鱼形的模子，精致的双层饭盒，刮粘锅底饭渣的草莓状小塑料片，花式切片器，各式各样的香水动物橡皮，粘双眼皮的液体贴纸，花... (展开)
4295 171 123回应 收起
木卫二 2009-04-07 10:41:23

## 总是慢上一拍

可能夏日漫漫的气息太过宁静，加上缺少激起观众好奇心的情节点，影片意在冲击戛纳结果未能如愿。第二遍观看时我深陷其中，这样的家庭剧不会真正结束。 ——《日本时报》Mark Schilling 子女回到父母居住的老家，这部作品有意无意地带上了一层致敬小津的色彩。平常生活中的人生... (展开)
1088 85 57回应 收起
愛永 2009-04-30 03:15:51

## 長長的路上，總會有光

这篇影评可能有剧透

如果，人生是一條長長的路，陪我們走最長一段路的，就是家人。 一路上，我們會遇到許多意想不到的事，有的十分美好，有的萬般痛苦，每一段路，也各自會有與我們並肩同行的人，伴我們度過不同的生命時刻。而家人，很少與我們並肩同行，總是在一定的距離之外，或前或後，不在圓的... (展开)
734 39 40回应 收起
简单心理 2017-11-22 16:12:51

## 人生路上步履不停，为何总是慢一拍

这篇影评可能有剧透

有人说，有的导演一生只拍一种电影。是枝裕和就是这样的导演。 无论是《如父如子》还是《海街日记》，再或者是今天想介绍给大家的《步履不停》，是枝裕和的故事里总包含着两个不变的元素：家庭和亲子。 佳作之所以为佳作，就是因为它并不只是展现生活中美好的一面。是枝裕和是... (展开)
473 1 18回应 收起
木卫二 2009-04-25 13:27:29

## 那些没赶上的事情

■入评理由：《电影旬报》年度十佳，亚洲电影大奖最佳导演奖，有人说这是最好的一部是枝裕和作品。 　　■片名：《步履不停》 　　■导演：是枝裕和 　　■主演：阿部宽 　　■读家：木卫二 　　■推荐指数：★★★★★★ 　　■一句话点评：小津时代没能解决的家庭... (展开)
254 29 10回应 收起
布宜諾斯 2011-11-23 08:23:28

## 三天走不出电影情绪

文/布宜诺斯 有人说，是枝裕和的电影里能看到小津安二郎的影子。的确，在这个浮躁的时代，他是少有的一位导演，愿意思考死亡，镜头沉静如水。在这部[步履不停]中，导演仍旧没有放弃死亡的议题，仍是以死来予给生之重量，但这次会让观众不住想象，一个人要对父母... (展开)
146 15 5回应 收起
陈问问 2009-08-01 12:47:57

## 真是谁也停不下的步履

为什么要写这么一个平凡的家庭故事？ 导演是枝裕和说：“ 因为我想要写一个什么事都没发生的故事……一个什么事都没发生， 但却很有趣的故事。因为大家人生当中并不会常发生什么了不起的大事件，但是日常生活却很有趣不是吗？这次的电影，我想要描写的就是日常生活中的悲剧、... (展开)
127 14 12回应 收起
快乐小张 2018-08-07 11:17:10 #《步履不停》有哪些戳你泪点的情节？

## 《步履不停》有哪些戳你泪点的情节？

1.儿子，父亲，爷爷，三个人一起去海边玩。 儿子最年轻，跑的最快，爷爷年纪最大走的最慢，但是父亲为了爷爷的安全，为了他的尊严，故意玩手机放慢自己的脚步，让爷爷先走，确保自己的儿子和父亲都在自己的视线中。 忽然间明白了为什么我妈总是让我牵着外公的手，我习惯大步流... (展开)
129 1 16回应 收起
老鹿 2018-08-08 15:57:05 #《步履不停》反映了是枝裕和的哪些个人风格？

## “越亲近，越互相伤害”——步履不停的思考生命的本质

“所谓主角，是指即便没有出现在画面上，但仍然支配着整部电影的人。但到底支配着什么呢？就是台词动作、情感，有时还包括剪辑。总而言之，电影主角就是与镜头这一侧的导演呼吸频率同步的人。”（p.133，是枝裕和） 影片通过围绕家人拜祭大儿子而在两日之内产生的生活琐事来映... (展开)
125 9 7回应 收起

> 更多影评 1466篇

添加新讨论

## 讨论区 · · · · · ·

我翻译了新的字幕！ | 来自行随影 | 2 回应 | 2022-11-23 07:32:45
中日家庭电影区隔 | 来自歪猴 |  | 2022-11-16 14:33:47
阿部宽找到的那张画着画的纸上写的什么内容？ | 来自pacer | 2 回应 | 2022-11-16 14:26:57
奶奶不满意阿部宽的新媳妇，但是为什么还给贵重的... | 来自Filly | 14 回应 | 2022-11-05 12:06:08
奶奶到底想不想抱孙？ | 来自wenun | 4 回应 | 2022-11-05 11:52:51

> 去这部影片的讨论区（全部178条）

## 关于《步履不停》的问题 · · · · · · ( 全部27个 )

- 母亲每年在长子祭日叫来那个被救的孩子，是不是太残酷了？ 20人回答
- 日本的演歌是什么歌？ 4人回答

> 全部27个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 【大爱の日剧♂电影♀动画全收录】 (狷介有乌青)
- 《身不在场》：木卫二在纸媒时代的电影推荐 (木卫二)
- 治愈系日影 (阿俢)

## 谁在看这部电影 · · · · · ·

- 又是凌晨两点半
  6分钟前 想看
- 哈哈哈哈12305
  11分钟前 看过
- momo
  11分钟前 想看

372843人看过 / 313926人想看

订阅步履不停的评论:
feed: rss 2.0